@@ -21,7 +21,9 @@ class CLI(object):
 
         # models arguments
         "name": "model_name",
-        "type": "model_type"
+        "model": "model_name",
+        "type": "model_type",
+        "tg": "target"
     }
 
     def __init__(self):
@@ -38,6 +40,7 @@ class CLI(object):
 
                     igel <command> [<args>]
                     - Available sub-commands at the moment are:
+                       init                initialize a yaml file with default parameters
                        fit                 fits a model
                        evaluate            evaluate the performance of a pre-fitted model
                        predict             Predicts using a pre-fitted model
@@ -79,6 +82,9 @@ class CLI(object):
 
                     igel -h                                                             # print this help guide
 
+                    igel init -type regression -model RandomForest                      # automatically create a yaml file in the working directory
+                                                                                        # with some default parameters to get you started fast
+
                     igel models                                                         # type this to get a list of supported models
 
                     igel models -type regression -name RandomForest                     # this will give you a help on how to use the
@@ -159,6 +165,9 @@ class CLI(object):
     def help(self, *args, **kwargs):
         self.parser.print_help()
 
+    def init(self, *args, **kwargs):
+        Igel.create_init_mock_file(**self.dict_args)
+
     def fit(self, *args, **kwargs):
         print("""
          _____          _       _
@@ -301,6 +310,7 @@ class CLI(object):
         out.append(hline)
         return "\n".join(out)
 
+
 def main():
     CLI()
 
