@@ -4,7 +4,9 @@ import os
 
 stats_dir = 'model_results'
 model_file = 'model.sav'
+init_file = 'igel.yaml'
 res_path = Path(os.getcwd()) / stats_dir
+init_file_path = Path(os.getcwd()) / init_file
 description_file = 'description.json'
 evaluation_file = 'evaluation.json'
 predictions_file = 'predictions.csv'
@@ -17,13 +19,29 @@ configs = {
     "description_file": res_path / description_file,
     "evaluation_file": res_path / evaluation_file,
     "prediction_file": res_path / predictions_file,
+    "init_file_path": init_file_path,
 
     "dataset_props": {
-        "type": "csv"
+
+        "type": "csv",
+        "read_data_options": "default",
+        "split": {
+            "test_size": 0.2,
+            "shuffle": True,
+            "stratify": "default"
+        },
+        "preprocess": {
+            "missing_values": "mean",
+            "scale": {
+                "method": "standard",
+                "target": "inputs"
+            }
+        }
+
     },
     "model_props": {
-        "type": "regression",
-        "algorithm": "linear regression",
+        "type": "classification",
+        "algorithm": "RandomForest",
         "arguments": "default"
     },
 
